//##########################################################################
//           http://www.cnpopsoft.com           
//          VB & C# source code and articles for free !!!           
//                Davidwu                       
//##########################################################################

// 2008/5/9, by Davidwu :
// 1.Disable the animation in designtime mode. (thanks for Johnny J.!)
// 2.Fix the menus' check state.
// 3.Fix the positionRect serialize error bug.
// 4.Refresh the control after changing the style.
//
// Thanks! have fun!:)

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace FrontDesk
{
    public partial class VistaClock : UserControl
    {
        Timer timer = new Timer();
        Timer timer2 = new Timer();
        int h, m, s;
        float secondAngel = 0f;

        public enum VistaClockStyle
        {
            Silver, Black, Red, Flower
        }

        #region Properties

        private bool showSecond = true;
        /// <summary>
        /// specify the second hand is visible or not.
        /// </summary>
        public bool ShowSecond
        {
            get { return showSecond; }
            set { showSecond = value; this.Invalidate(); }
        }

        private bool secondSpring = true;
        /// <summary>
        /// specify the spring affect is on/off.
        /// </summary>
        public bool SecondSpring
        {
            get { return secondSpring; }
            set { secondSpring = value; this.Invalidate(); }
        }

        private VistaClockStyle style = VistaClockStyle.Silver;
        /// <summary>
        /// Clock visual type
        /// </summary>
        public VistaClockStyle Style
        {
            get { return style; }
            set { style = value; this.Invalidate(); }
        }

        private CustomRectangle positionRect = new CustomRectangle();
        /// <summary>
        /// position rectangle
        /// </summary>
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public CustomRectangle PositionRect
        {
            get { return positionRect; }
            set { positionRect = value; this.Invalidate(); }
        }

        #region ReadOnly Properties

        private Image Image
        {
            get
            {
                if (style == VistaClockStyle.Black)
                    return global::FrontDesk.Properties.Resources.trad;
                else if (style == VistaClockStyle.Silver)
                    return global::FrontDesk.Properties.Resources.system1;
                else if (style == VistaClockStyle.Red)
                    return global::FrontDesk.Properties.Resources.modern1;
                else
                    return global::FrontDesk.Properties.Resources.flower1;
            }
        }

        private Image ImageH
        {
            get
            {
                if (style == VistaClockStyle.Black)
                    return global::FrontDesk.Properties.Resources.trad_h1;
                else if (style == VistaClockStyle.Silver)
                    return global::FrontDesk.Properties.Resources.system_h1;
                else if (style == VistaClockStyle.Red)
                    return global::FrontDesk.Properties.Resources.modern_h1;
                else
                    return global::FrontDesk.Properties.Resources.flower_h1;
            }
        }

        private Image ImageM
        {
            get
            {
                if (style == VistaClockStyle.Black)
                    return global::FrontDesk.Properties.Resources.trad_m1;
                else if (style == VistaClockStyle.Silver)
                    return global::FrontDesk.Properties.Resources.system_m1;
                else if (style == VistaClockStyle.Red)
                    return global::FrontDesk.Properties.Resources.modern_m1;
                else
                    return global::FrontDesk.Properties.Resources.flower_m1;
            }
        }

        private Image ImageS
        {
            get
            {
                if (style == VistaClockStyle.Black)
                    return global::FrontDesk.Properties.Resources.trad_s1;
                else if (style == VistaClockStyle.Silver)
                    return global::FrontDesk.Properties.Resources.system_s1;
                else if (style == VistaClockStyle.Red)
                    return global::FrontDesk.Properties.Resources.modern_s1;
                else
                    return global::FrontDesk.Properties.Resources.flower_s1;
            }
        }

        private Image ImageDot
        {
            get
            {
                if (style == VistaClockStyle.Black)
                    return global::FrontDesk.Properties.Resources.trad_dot1;
                else if (style == VistaClockStyle.Silver)
                    return global::FrontDesk.Properties.Resources.system_dot1;
                else if (style == VistaClockStyle.Red)
                    return global::FrontDesk.Properties.Resources.modern_dot1;
                else
                    return global::FrontDesk.Properties.Resources.flower_dot1;
            }
        }

        private Image ImageHighlight
        {
            get
            {
                if (style == VistaClockStyle.Black)
                    return global::FrontDesk.Properties.Resources.trad_highlights1;
                else if (style == VistaClockStyle.Silver)
                    return global::FrontDesk.Properties.Resources.system_highlights1;
                else if (style == VistaClockStyle.Red)
                    return global::FrontDesk.Properties.Resources.modern_highlights1;
                else
                    return global::FrontDesk.Properties.Resources.flower_highlights1;
            }
        }
        #endregion
        #endregion

        #region Methods

        public VistaClock()
        {
            InitializeComponent();

            this.DoubleBuffered = true;
            this.BackColor = Color.Transparent;

            timer.Interval = 1000;
            timer.Enabled = true;
            timer2.Interval = 30;
            timer2.Enabled = false;

            this.MouseUp += new MouseEventHandler(VistaClock_MouseUp);
            this.Paint += new PaintEventHandler(Clock_Paint);
            this.Resize += new EventHandler(Clock_Resize);
            timer.Tick += new EventHandler(timer_Tick);
            timer2.Tick += new EventHandler(timer2_Tick);

            Clock_Resize(this, null);
            timer_Tick(timer, null);
        }

        void timer2_Tick(object sender, EventArgs e)
        {
            secondAngel = s / 60f * 360f;
            this.Invalidate(positionRect.ToRectangle());
            timer2.Enabled = false;
        }

        void VistaClock_MouseUp(object sender, MouseEventArgs e)
        {
            if (e.Button == MouseButtons.Right)
            {
                mnuShowSpring.Checked = secondSpring;
                mnuShowSecond.Checked = showSecond;
                contextMenuStrip1.Show(this, e.Location);
            }
        }

        void Clock_Resize(object sender, EventArgs e)
        {
            if (positionRect == null) positionRect = new CustomRectangle(); 
            positionRect.Width = (int)Image.Width;
            positionRect.Height = (int)Image.Height;
            positionRect.Top = (int)(this.ClientSize.Height < Image.Height ? 0 : (this.ClientSize.Height - Image.Height) / 2f);
            positionRect.Left = (int)(this.ClientSize.Width < Image.Width ? 0 : (this.ClientSize.Width - Image.Width) / 2f);

            this.Invalidate();
        }

        void timer_Tick(object sender, EventArgs e)
        {
            if (DesignMode) return;
            UpdateDateTime();

            if (showSecond)
            {
                if (!secondSpring)
                    secondAngel = s / 60f * 360f;
                else
                    secondAngel = s / 60f * 360f + 4;
            }

            if (showSecond && secondSpring) timer2.Enabled = true;

            this.Invalidate(positionRect.ToRectangle());
        }

        private void UpdateDateTime()
        {
            h = DateTime.Now.Hour;
            m = DateTime.Now.Minute;
            s = DateTime.Now.Second;
        }

        void Clock_Paint(object sender, PaintEventArgs e)
        {
            //Draw Background
            e.Graphics.DrawImage(Image, positionRect.ToRectangle());

            //HourSize13129
            e.Graphics.TranslateTransform(positionRect.X + positionRect.Width / 2f, positionRect.Y + positionRect.Height / 2f);
            e.Graphics.RotateTransform(h / 12f * 360 + m / 60f * 360f / 12f);
            e.Graphics.DrawImage(ImageH, -6.5f, -64.5f, 13, 129);
            //Minute
            e.Graphics.ResetTransform();
            e.Graphics.TranslateTransform(positionRect.X + positionRect.Width / 2f, positionRect.Y + positionRect.Height / 2f);
            e.Graphics.RotateTransform(m / 60f * 360);
            e.Graphics.DrawImage(ImageM, -6.5f, -64.5f, 13, 129);
            //Second
            if (showSecond)
            {
                e.Graphics.ResetTransform();
                e.Graphics.TranslateTransform(positionRect.X + positionRect.Width / 2f, positionRect.Y + positionRect.Height / 2f);
                e.Graphics.RotateTransform(secondAngel);
                e.Graphics.DrawImage(ImageS, -6.5f, -64.5f, 13, 129);
            }
            //Dot
            e.Graphics.ResetTransform();
            e.Graphics.TranslateTransform(positionRect.X + positionRect.Width / 2f, positionRect.Y + positionRect.Height / 2f);
            e.Graphics.DrawImage(ImageDot, -6.5f, -64.5f, 13, 129);
            e.Graphics.ResetTransform();

            //Glass affect
            e.Graphics.DrawImage(ImageHighlight, positionRect.ToPointF());
        }


        #endregion

        #region Menu Event Handler

        private void mnuSilver_Click(object sender, EventArgs e)
        {
            style = VistaClockStyle.Silver;
            this.Invalidate();
        }

        private void mnuBlack_Click(object sender, EventArgs e)
        {
            style = VistaClockStyle.Black;
            this.Invalidate();
        }

        private void mnuRed_Click(object sender, EventArgs e)
        {
            style = VistaClockStyle.Red;
            this.Invalidate();
        }

        private void mnuFlower_Click(object sender, EventArgs e)
        {
            style = VistaClockStyle.Flower;
            this.Invalidate();
        }

        private void mnuShowSecond_Click(object sender, EventArgs e)
        {
            mnuShowSecond.Checked = !mnuShowSecond.Checked;
            showSecond = mnuShowSecond.Checked;
            this.Invalidate();
        }

        private void mnuShowSpring_Click(object sender, EventArgs e)
        {
            mnuShowSpring.Checked = !mnuShowSpring.Checked;
            secondSpring = mnuShowSpring.Checked;
            this.Invalidate();
        }

        private void contextMenuStrip1_Opening(object sender, CancelEventArgs e)
        {
            mnuBlack.Checked = (style == VistaClockStyle.Black);
            mnuFlower.Checked = (style == VistaClockStyle.Flower);
            mnuRed.Checked = (style == VistaClockStyle.Red);
            mnuSilver.Checked = (style == VistaClockStyle.Silver);
            mnuShowSecond.Checked = showSecond;
            mnuShowSpring.Checked = secondSpring;
        }

        #endregion

    }
}
